@@ -9,7 +9,7 @@ var languageNames = {
 "bs": "Bosnio",
 "bg": "Búlgaro",
 "ca": "Catalán",
-"ca-valencia": "Catalan (Valencia)",
+"ca-valencia": "Catalán (Valencia)",
 "zh-CN": "Chinés (Simplificado)",
 "zh-TW": "Chinés (Tradicional)",
 "hr": "Croata",
@@ -48,15 +48,15 @@ var languageNames = {
 "om": "Oromo",
 "pl": "Polaco",
 "pt": "Portugués",
-"pt-BR": "Portuguese (Brazil)",
+"pt-BR": "Portugués (Brasil)",
 "ro": "Romanés",
 "ru": "Ruso",
 "sid": "Sidama",
 "si": "Sinhala",
 "sk": "Eslovaco",
 "sl": "Esloveno",
-"dsb": "Sorbian (Lower)",
-"hsb": "Sorbian (Upper)",
+"dsb": "Sorbio (Baixo)",
+"hsb": "Sorbio (Alto)",
 "es": "Castelán",
 "sv": "Sueco",
 "tg": "Taxico",
